diff --git a/suite-native/module-send/src/screens/SendAccountsScreen.tsx b/suite-native/module-send/src/screens/SendAccountsScreen.tsx
index ce07bb68609..edfab8bb415 100644
--- a/suite-native/module-send/src/screens/SendAccountsScreen.tsx
+++ b/suite-native/module-send/src/screens/SendAccountsScreen.tsx
@@ -10,9 +10,9 @@ import {
} from '@suite-native/navigation';
import { AccountKey } from '@suite-common/wallet-types';
// TODO: So far we do not want enable send form for any other network than Bitcoin Testnet and Regtest.
// This filter will be removed in a follow up PR.
-const TESTNET_FILTER = 'TEST';
+const BITCOIN_LIKE_FILTER = 'bitcoin';
export const SendAccountsScreen = ({
navigation,
@@ -28,8 +28,11 @@ export const SendAccountsScreen = ({
screenHeader={}
subheader={} />}
>
- {/* TODO: Enable filtering same as receive screen has. */}
-
+ {/* TODO: Enable filtering same as receive screen account list has. */}
+
);
};
@@ -10,9 +10,9 @@ import {
} from '@suite-native/navigation';
import { AccountKey } from '@suite-common/wallet-types';
-// TODO: So far we do not want enable send form for any other network than Bitcoin Testnet and Regtest.
+// TODO: So far we do not want enable send form for any other networkS than Bitcoin-like coins.
// This filter will be removed in a follow up PR.